@@ -33,6 +33,16 @@ text_document_definition  <- function(self, id, params) {
 
 }
 
+# Request
+text_document_type_definition  <- function(self, id, params) {
+
+}
+
+# Request
+text_document_implementation  <- function(self, id, params) {
+
+}
+
 # Request
 text_document_references  <- function(self, id, params) {
 
@@ -73,6 +83,17 @@ document_link_resolve  <- function(self, id, params) {
 
 }
 
+# Request
+text_document_document_color  <- function(self, id, params) {
+
+}
+
+# Request
+text_document_color_presentation  <- function(self, id, params) {
+
+}
+
+
 # Request
 text_document_formatting  <- function(self, id, params) {
     textDocument <- params$textDocument
@@ -99,3 +120,13 @@ text_document_on_type_formatting  <- function(self, id, params) {
 text_document_rename  <- function(self, id, params) {
 
 }
+
+# Request
+text_document_prepare_rename  <- function(self, id, params) {
+
+}
+
+# Request
+text_document_folding_range  <- function(self, id, params) {
+
+}
